@@ -164,8 +164,14 @@ function configure_generic_switch {
             done
         fi
     fi
+    # NOTE(TheJulia): This is not respected presently with uwsgi launched
+    # neutron as it auto-identifies it's configuration files.
     neutron_server_config_add $GENERIC_SWITCH_INI_FILE
 
+    # NOTE(JayF): It's possible in some rare cases this config doesn't exist
+    #             if so, no big deal, iniset is used in devstack and should
+    #             not lose our changes. See `write_uwsgi_config` in lib/apache
+    iniset -sudo /etc/neutron/neutron-api-uwsgi.ini uwsgi env OS_NEUTRON_CONFIG_FILES='/etc/neutron/neutron.conf;/etc/neutron/plugins/ml2/ml2_conf.ini;/etc/neutron/plugins/ml2/ml2_conf_genericswitch.ini'
 }
 
 function add_generic_switch_to_ml2_config {
@@ -183,6 +189,7 @@ function add_generic_switch_to_ml2_config {
 
     if [[ -n "$key_file" ]]; then
         populate_ml2_config $GENERIC_SWITCH_INI_FILE $switch_name key_file=$key_file
+        populate_ml2_config $GENERIC_SWITCH_INI_FILE $switch_name use_keys=True
     elif [[ -n "$password" ]]; then
         populate_ml2_config $GENERIC_SWITCH_INI_FILE $switch_name password=$password
     fi
@@ -235,7 +242,29 @@ function ngs_configure_tempest {
     if [ $GENERIC_SWITCH_USER_MAX_SESSIONS -gt 0 ]; then
         iniset $TEMPEST_CONFIG ngs port_dlm_concurrency $(($GENERIC_SWITCH_USER_MAX_SESSIONS * 2))
     fi
-    iniset $TEMPEST_CONFIG baremetal_feature_enabled trunks_supported True
+    if [[ "${ML2_L3_PLUGIN:-}" =~ "trunk" ]]; then
+        iniset $TEMPEST_CONFIG baremetal_feature_enabled trunks_supported True
+    fi
+}
+
+function ngs_restart_neutron {
+    echo_summary "NGS doing required neutron restart. Stopping neutron."
+    # NOTE(JayF) In practice restarting OVN causes problems, I'm not sure why.
+    # This avoids the restart.
+    local existing_skip_stop_ovn
+    SKIP_STOP_OVN=True
+    # We are changing the base config, and need ot restart the neutron services
+    stop_neutron
+    # NOTE(JayF): Neutron services are initialized in a particular order, this appears to
+    # match that order as currently defined in stack.sh (2025-05-22).
+    # TODO(JayF): Introduce a function in upstream devstack that documents this order so
+    # ironic won't break anytime initialization steps are rearranged.
+    echo_summary "NGS starting neutron service"
+    start_neutron_service_and_check
+    echo_summary "NGS started neutron service, now launch neutron agents"
+    start_neutron
+    echo_summary "NGS required neutron restart completed."
+    SKIP_STOP_OVN=False
 }
 
 # check for service enabled
@@ -247,7 +276,7 @@ if is_service_enabled generic_switch; then
         install_generic_switch
 
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
-        # Configure after the other layer 1 and 2 services have been configured
+        # Configure after the other layer 1 and 2 services have been started
         echo_summary "Configuring Generic_switch ML2"
 
         # Source ml2 plugin, set default config
@@ -259,7 +288,22 @@ if is_service_enabled generic_switch; then
             Q_PLUGIN_CLASS="ml2"
         fi
 
+        # TODO(JayF): This currently relies on winning a race, as many of the
+        #             files modified by this method are created during this
+        #             phase. In practice it works, but moving forward we likely
+        #             need a supported-by-devstack/neutron-upstream method to 
+        #             ensure this is done at the right moment.
         configure_generic_switch
+
+        if is_service_enabled neutron; then
+            # TODO(JayF): Similarly, we'd like to restart neutron to ensure
+            #             our config changes have taken effect; we can't do 
+            #             that reliably here because it may not be fully
+            #             configured, and extra phase is too late.
+            echo_summary "Skipping ngs_restart_neutron"
+            #ngs_restart_neutron
+        fi
+
     elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
         if is_service_enabled tempest; then
             echo_summary "Configuring Tempest NGS"
