@@ -43,7 +43,87 @@ class NetmikoSwitchTestBase(fixtures.TestWithFixtures):
         device_cfg = {'device_type': 'netmiko_base',
                       'ip': 'host'}
         device_cfg.update(extra_cfg)
-        return netmiko_devices.NetmikoSwitch(device_cfg)
+        switch = netmiko_devices.NetmikoSwitch(device_cfg)
+        switch.ADD_NETWORK = (
+            'add network {segmentation_id} {network_id} {network_name}',
+        )
+        switch.DELETE_NETWORK = (
+            'delete network {segmentation_id} {network_id} {network_name}',
+        )
+        switch.PLUG_PORT_TO_NETWORK = (
+            'plug port {port} to network {segmentation_id}',
+        )
+        switch.DELETE_PORT = (
+            'delete port {port} from network {segmentation_id}',
+        )
+        switch.PLUG_BOND_TO_NETWORK = (
+            'plug bond {bond} to network {segmentation_id}',
+        )
+        switch.UNPLUG_BOND_FROM_NETWORK = (
+            'unplug bond {bond} from network {segmentation_id}',
+        )
+        switch.ADD_NETWORK_TO_TRUNK = (
+            'add network {segmentation_id} to trunk {port}',
+        )
+        switch.REMOVE_NETWORK_FROM_TRUNK = (
+            'remove network {segmentation_id} from trunk {port}',
+        )
+        switch.ENABLE_PORT = (
+            'enable port {port}',
+        )
+        switch.DISABLE_PORT = (
+            'disable port {port}',
+        )
+        switch.ENABLE_BOND = (
+            'enable bond {bond}',
+        )
+        switch.DISABLE_BOND = (
+            'disable bond {bond}',
+        )
+        switch.SET_NATIVE_VLAN = (
+            'set native vlan to {segmentation_id} on port {port}',
+        )
+        switch.DELETE_NATIVE_VLAN = (
+            'delete native vlan {segmentation_id} on port {port}',
+        )
+        switch.SET_NATIVE_VLAN_BOND = (
+            'set native vlan to {segmentation_id} on bond {bond}',
+        )
+        switch.DELETE_NATIVE_VLAN_BOND = (
+            'delete native vlan {segmentation_id} on bond {bond}',
+        )
+        switch.ADD_NETWORK_TO_BOND_TRUNK = (
+            'add network {segmentation_id} to bond trunk {port}',
+        )
+        switch.DELETE_NETWORK_ON_BOND_TRUNK = (
+            'delete network {segmentation_id} on bond trunk {port}',
+        )
+        switch.ADD_SECURITY_GROUP = (
+            "add security group {security_group}",
+        )
+        switch.ADD_SECURITY_GROUP_COMPLETE = (
+            "add security group complete",
+        )
+        switch.REMOVE_SECURITY_GROUP = (
+            "remove security group {security_group}",
+        )
+        switch.ADD_SECURITY_GROUP_RULE_INGRESS = (
+            "add ingress rule {protocol} "
+            "source {remote_ip_prefix} "
+            "port {port_range_min} to {port_range_max}",
+        )
+        switch.ADD_SECURITY_GROUP_RULE_EGRESS = (
+            "add egress rule {protocol} "
+            "source {remote_ip_prefix} "
+            "port {port_range_min} to {port_range_max}",
+        )
+        switch.BIND_SECURITY_GROUP = (
+            "bind security group {security_group} to port {port}",
+        )
+        switch.UNBIND_SECURITY_GROUP = (
+            "unbind security group {security_group} from port {port}",
+        )
+        return switch
 
 
 class TestNetmikoSwitch(NetmikoSwitchTestBase):
@@ -64,7 +144,9 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                 'NetmikoSwitch.check_output', autospec=True)
     def test_add_network(self, m_check, m_sctd):
         self.switch.add_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
-        m_sctd.assert_called_with(self.switch, [])
+        m_sctd.assert_called_with(self.switch, [
+            'add network 22 0ae071f55be943e480eae41fefe85b21 '
+            '0ae071f55be943e480eae41fefe85b21'])
         m_check.assert_called_once_with(self.switch,
                                         'fake output', 'add network')
 
@@ -76,7 +158,12 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
     def test_add_network_with_trunk_ports(self, m_check, m_sctd):
         switch = self._make_switch_device({'ngs_trunk_ports': 'port1, port2'})
         switch.add_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
-        m_sctd.assert_called_with(switch, [])
+        m_sctd.assert_called_with(switch, [
+            'add network 22 0ae071f55be943e480eae41fefe85b21 '
+            '0ae071f55be943e480eae41fefe85b21',
+            'add network 22 to trunk port1',
+            'add network 22 to trunk port2'
+        ])
         m_check.assert_called_once_with(switch, 'fake output', 'add network')
 
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
@@ -97,7 +184,9 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                 'NetmikoSwitch.check_output', autospec=True)
     def test_del_network(self, m_check, m_sctd):
         self.switch.del_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
-        m_sctd.assert_called_with(self.switch, [])
+        m_sctd.assert_called_with(self.switch, [
+            'delete network 22 0ae071f55be943e480eae41fefe85b21 '
+            '0ae071f55be943e480eae41fefe85b21'])
         m_check.assert_called_once_with(self.switch,
                                         'fake output', 'delete network')
 
@@ -109,7 +198,11 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
     def test_del_network_with_trunk_ports(self, m_check, m_sctd):
         switch = self._make_switch_device({'ngs_trunk_ports': 'port1, port2'})
         switch.del_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
-        m_sctd.assert_called_with(switch, [])
+        m_sctd.assert_called_with(switch, [
+            'remove network 22 from trunk port1',
+            'remove network 22 from trunk port2',
+            'delete network 22 0ae071f55be943e480eae41fefe85b21 '
+            '0ae071f55be943e480eae41fefe85b21'])
         m_check.assert_called_once_with(switch,
                                         'fake output', 'delete network')
 
@@ -131,7 +224,8 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                 'NetmikoSwitch.check_output', autospec=True)
     def test_plug_port_to_network(self, m_check, m_sctd):
         self.switch.plug_port_to_network(2222, 22)
-        m_sctd.assert_called_with(self.switch, [])
+        m_sctd.assert_called_with(self.switch, [
+            'plug port 2222 to network 22'])
         m_check.assert_called_once_with(self.switch,
                                         'fake output', 'plug port')
 
@@ -143,7 +237,10 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
     def test_plug_port_has_default_vlan(self, m_check, m_sctd):
         switch = self._make_switch_device({'ngs_port_default_vlan': '20'})
         switch.plug_port_to_network(2222, 22)
-        m_sctd.assert_called_with(switch, [])
+        m_sctd.assert_called_with(switch, [
+            'delete port 2222 from network 20',
+            'plug port 2222 to network 22'
+        ])
         m_check.assert_called_once_with(switch, 'fake output', 'plug port')
 
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
@@ -155,7 +252,10 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
         switch = self._make_switch_device(
             {'ngs_disable_inactive_ports': 'true'})
         switch.plug_port_to_network(2222, 22)
-        m_sctd.assert_called_with(switch, [])
+        m_sctd.assert_called_with(switch, [
+            'enable port 2222',
+            'plug port 2222 to network 22'
+        ])
         m_check.assert_called_once_with(switch, 'fake output', 'plug port')
 
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
@@ -165,7 +265,8 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                 'NetmikoSwitch.check_output', autospec=True)
     def test_delete_port(self, m_check, m_sctd):
         self.switch.delete_port(2222, 22, trunk_details={})
-        m_sctd.assert_called_with(self.switch, [])
+        m_sctd.assert_called_with(self.switch, [
+            'delete port 2222 from network 22'])
         m_check.assert_called_once_with(self.switch,
                                         'fake output', 'unplug port')
 
@@ -177,7 +278,10 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
     def test_delete_port_has_default_vlan(self, m_check, m_sctd):
         switch = self._make_switch_device({'ngs_port_default_vlan': '20'})
         switch.delete_port(2222, 22, trunk_details={})
-        m_sctd.assert_called_with(switch, [])
+        m_sctd.assert_called_with(switch, [
+            'delete port 2222 from network 22',
+            'add network 20 20 20',
+            'plug port 2222 to network 20'])
         m_check.assert_called_once_with(switch, 'fake output', 'unplug port')
 
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
@@ -189,13 +293,237 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
         switch = self._make_switch_device(
             {'ngs_disable_inactive_ports': 'true'})
         switch.delete_port(2222, 22)
-        m_sctd.assert_called_with(switch, [])
+        m_sctd.assert_called_with(switch, [
+            'delete port 2222 from network 22',
+            'disable port 2222'])
         m_check.assert_called_once_with(switch, 'fake output', 'unplug port')
 
+    def test__validate_rule(self):
+        empty_rule = mock.Mock(
+            protocol=None,
+            port_range_min=None,
+            port_range_max=None,
+        )
+        rule = mock.Mock(
+            protocol='tcp',
+            port_range_min='8080',
+            port_range_max='8088',
+        )
+        self.assertFalse(self.switch._validate_rule(empty_rule))
+        self.assertTrue(self.switch._validate_rule(rule))
+        self.switch.SUPPORT_SG_PORT_RANGE = False
+        self.assertRaises(
+            exc.GenericSwitchSecurityGroupRuleNotSupported,
+            self.switch._validate_rule, rule)
+
+    def test__prepare_security_group_rule(self):
+        # empty rule
+        rule = mock.Mock(
+            ethertype=None,
+            protocol=None,
+            direction=None,
+            remote_ip_prefix=None,
+            normalized_cidr=None,
+            port_range_min=None,
+            port_range_max=None,
+        )
+        self.assertEqual(
+            {
+                'security_group': 'ngs-1234'
+            },
+            self.switch._prepare_security_group_rule('1234', rule)
+        )
+        # full rule
+        rule = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='ingress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='22',
+            port_range_max='23'
+        )
+        self.assertEqual(
+            {
+                'direction': 'ingress',
+                'ethertype': 'IPv4',
+                'normalized_cidr': '0.0.0.0/0',
+                'port_range_max': '23',
+                'port_range_min': '22',
+                'protocol': 'tcp',
+                'remote_ip_prefix': '0.0.0.0/0',
+                'security_group': 'ngs-1234'
+            },
+            self.switch._prepare_security_group_rule('1234', rule))
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device',
+                return_value='fake output', autospec=True)
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.check_output', autospec=True)
+    def test_add_security_group(self, m_check, m_sctd):
+        rule1 = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='ingress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='22',
+            port_range_max='23'
+        )
+        rule2 = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='egress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='80',
+            port_range_max='80'
+        )
+        sg = mock.Mock()
+        sg.id = '1234'
+        sg.rules = [rule1, rule2]
+        switch = self._make_switch_device(
+            {'ngs_disable_inactive_ports': 'true'})
+        switch.add_security_group(sg)
+        m_sctd.assert_called_with(switch, [
+            'add security group ngs-1234',
+            'add ingress rule tcp source 0.0.0.0/0 '
+            'port 22 to 23',
+            'add egress rule tcp source 0.0.0.0/0 '
+            'port 80 to 80',
+            'add security group complete'])
+        m_check.assert_called_once_with(switch, 'fake output',
+                                        'add security group')
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device',
+                return_value='fake output', autospec=True)
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.check_output', autospec=True)
+    def test_add_security_group_no_range(self, m_check, m_sctd):
+        rule1 = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='ingress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='22',
+            port_range_max='23'
+        )
+        rule2 = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='egress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='80',
+            port_range_max='80'
+        )
+        sg = mock.Mock()
+        sg.id = '1234'
+        sg.rules = [rule1, rule2]
+        switch = self._make_switch_device(
+            {'ngs_disable_inactive_ports': 'true'})
+
+        switch.SUPPORT_SG_PORT_RANGE = False
+        self.assertRaises(
+            exc.GenericSwitchSecurityGroupRuleNotSupported,
+            switch.add_security_group, sg)
+        m_sctd.assert_not_called()
+        m_check.assert_not_called()
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device',
+                return_value='fake output', autospec=True)
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.check_output', autospec=True)
+    def test_add_security_group_no_egress(self, m_check, m_sctd):
+        rule1 = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='ingress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='22',
+            port_range_max='23'
+        )
+        rule2 = mock.Mock(
+            ethertype='IPv4',
+            protocol='tcp',
+            direction='egress',
+            remote_ip_prefix='0.0.0.0/0',
+            normalized_cidr='0.0.0.0/0',
+            port_range_min='80',
+            port_range_max='80'
+        )
+        sg = mock.Mock()
+        sg.id = '1234'
+        sg.rules = [rule1, rule2]
+        switch = self._make_switch_device(
+            {'ngs_disable_inactive_ports': 'true'})
+        switch.ADD_SECURITY_GROUP_RULE_EGRESS = None
+
+        self.assertRaises(
+            NotImplementedError,
+            switch.add_security_group, sg)
+        m_sctd.assert_not_called()
+        m_check.assert_not_called()
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device',
+                return_value='fake output', autospec=True)
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.check_output', autospec=True)
+    def test_del_security_group(self, m_check, m_sctd):
+        switch = self._make_switch_device(
+            {'ngs_disable_inactive_ports': 'true'})
+        switch.del_security_group('1234')
+        m_sctd.assert_called_with(switch, ['remove security group ngs-1234'])
+        m_check.assert_called_once_with(switch, 'fake output',
+                                        'delete security group')
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device',
+                return_value='fake output', autospec=True)
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.check_output', autospec=True)
+    def test_bind_security_group(self, m_check, m_sctd):
+        sg = mock.Mock()
+        sg.id = '1234'
+        sg.rules = []
+        switch = self._make_switch_device(
+            {'ngs_disable_inactive_ports': 'true'})
+        switch.bind_security_group(sg, 'port1', ['port1', 'port2'])
+        m_sctd.assert_called_with(switch, [
+            'remove security group ngs-1234',
+            'add security group ngs-1234',
+            'add security group complete',
+            'bind security group ngs-1234 to port port1',
+            'bind security group ngs-1234 to port port2'])
+        m_check.assert_called_once_with(switch, 'fake output',
+                                        'bind security group')
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device',
+                return_value='fake output', autospec=True)
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.check_output', autospec=True)
+    def test_unbind_security_group(self, m_check, m_sctd):
+        switch = self._make_switch_device(
+            {'ngs_disable_inactive_ports': 'true'})
+        switch.unbind_security_group('1234', 'port1', ['port2'])
+        m_sctd.assert_called_with(switch, [
+            'unbind security group ngs-1234 from port port1',
+            'bind security group ngs-1234 to port port2'])
+        m_check.assert_called_once_with(switch, 'fake output',
+                                        'unbind security group')
+
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
                 'NetmikoSwitch.plug_port_to_network',
                 return_value='fake output', autospec=True)
     def test_plug_bond_to_network_fallback(self, m_plug):
+        self.switch.PLUG_BOND_TO_NETWORK = None
         self.switch.plug_bond_to_network(2222, 22)
         m_plug.assert_called_with(self.switch, 2222, 22, trunk_details=None)
 
@@ -203,13 +531,18 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                 'NetmikoSwitch.delete_port',
                 return_value='fake output', autospec=True)
     def test_unplug_bond_from_network_fallback(self, m_delete):
+        self.switch.UNPLUG_BOND_FROM_NETWORK = None
         self.switch.unplug_bond_from_network(2222, 22)
         m_delete.assert_called_with(self.switch, 2222, 22, trunk_details=None)
 
     def test__format_commands(self):
-        self.switch._format_commands(
-            netmiko_devices.NetmikoSwitch.ADD_NETWORK,
+        self.switch.ADD_NETWORK = (
+            'add network {segmentation_id} {network_id}',
+        )
+        cmds = self.switch._format_commands(
+            self.switch.ADD_NETWORK,
             segmentation_id=22, network_id=22)
+        self.assertEqual(['add network 22 22'], cmds)
 
     @mock.patch.object(netmiko_devices.tenacity, 'wait_fixed',
                        return_value=tenacity.wait_fixed(0.01), autospec=True)
