@@ -39,6 +39,27 @@ class FakeDevice(devices.GenericSwitchDevice):
     def delete_port(self, p, s):
         pass
 
+    def add_subports_on_trunk(self, binding_profile, port_id, subports):
+        pass
+
+    def del_subports_on_trunk(self, binding_profile, port_id, subports):
+        pass
+
+    def add_security_group(self, sg):
+        pass
+
+    def update_security_group(self, sg):
+        pass
+
+    def del_security_group(self, sg_id):
+        pass
+
+    def bind_security_group(self, sg, port_id, port_ids):
+        pass
+
+    def unbind_security_group(self, sg_id, port_id, port_ids):
+        pass
+
 
 class TestGenericSwitchDevice(unittest.TestCase):
 
@@ -267,3 +288,24 @@ class TestDeviceManager(unittest.TestCase):
             "ciphers": ["blowfish-cbc", "3des-cbc"],
         }
         self.assertEqual(expected, algos)
+
+    def test_float_params_cast(self):
+        config = {
+            "device_type": 'netmiko_ovs_linux',
+            "ip": "10.1.2.3",
+            "username": "u",
+            "password": "p",
+            "conn_timeout": "20.0",
+            "global_delay_factor": "2.5",
+            "port": "2222",
+        }
+        device = devices.device_manager(config)
+
+        self.assertIsInstance(device.config["conn_timeout"], float)
+        self.assertEqual(device.config["conn_timeout"], 20.0)
+
+        self.assertIsInstance(device.config["global_delay_factor"], float)
+        self.assertEqual(device.config["global_delay_factor"], 2.5)
+
+        self.assertIsInstance(device.config["port"], int)
+        self.assertEqual(device.config["port"], 2222)
